##  Syncing Jira Issues with SAP LeanIX Fact Sheets
Sync the fact sheet type defined in the synchronization mappings for a project to the corresponding Jira issue type. This allows you to view the Jira issue name, status, and assignee of synced Jira issues on the Resources tab of the corresponding fact sheet in SAP LeanIX.
To sync a Jira issue with an SAP LeanIX fact sheet, follow these steps:
  1. Open the Glance view in a Jira issue.
  2. Choose Sync a Fact Sheet.
  3. Search for the fact sheet that you want to sync and select it. After the sync is complete, you will see the synced fact sheet under Synced Fact Sheet.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274217a97a441014877f9e01d62352dd_LowRes.png)
**Tip**
Tip
To unsync a fact sheet from an issue, open the Glance view, hover over the fact sheet name, and choose Unlink. Alternatively, you can remove the Jira issue listed on the Resources tab of the respective fact sheet.
